# Hatool Compiler

Command line tool to prepare [Hatool](https://github.com/akariv/hatool) scripts for use.

[Hatool](https://github.com/akariv/hatool) is a versatile scripted chatbot-style interface for Angular.

## Quickstart

```bash

$ pip install hatool-compiler

$ hatool <input-file> <output-file>

```

## Source file reference

See [Hatool script-file reference](https://github.com/akariv/hatool) for more details on writing script files.

